# sai
Simple AI interface to chat with your LLM models from the terminal

# Features

- [x] Pretty print real time responses in Markdown, using `rich` library.
- [x] Keep conversation context.
- [x] Autodetect and option to select models.
- [ ] Add support for custom prompts.
- [ ] Add conversation persistency (sessions).